@@ -19,7 +19,6 @@ client service
 import json
 import requests
 
-
 class ApiRequestManager:
     """
     Class to interact with general api request methods
@@ -42,20 +41,6 @@ class ApiRequestManager:
         self.cluster = cluster
         self.evergreen_enabled = True
 
-        auth = self.props.get_auth_token(cluster=self.cluster)
-
-        if auth is None or len(auth) == 0:
-            self.props.set_auth_token(
-                token=self.auth_token(),
-                cluster=self.cluster
-            )
-
-        self.session.headers.update(
-            {
-                self.x_auth_token_header: self.props.get_auth_token(cluster=self.cluster)
-            }
-        )
-
     def close_session(self):
         """
         Closes request session
@@ -95,7 +80,7 @@ class ApiRequestManager:
         self.verify_auth_token()
         self.verify_remote()
 
-    def auth_token(self):
+    def auth_token(self, query_params={}):
         """
         Authenticates the given credentials and retrieves auth token
 
@@ -115,10 +100,12 @@ class ApiRequestManager:
             post_response = self.session.post(
                 url,
                 headers=self.content_type_header,
-                data=json.dumps(data)
+                data=json.dumps(data),
+                params=query_params
             )
 
             if post_response.status_code == 200:
+
                 return json.loads(post_response.content)["authToken"]
 
             raise Exception(post_response.content)
