@@ -120,6 +120,7 @@ class Pipelines(ApiRequestManager):
         final_url = self.apply_map_attributes_url.format(org_id, pipeline_id, component)
 
         header = self.build_header(
+            aut_token=self.props.get_auth_token(cluster=self.cluster),
             org_id=org_id,
             others=self.delete_content_type_header
         )
@@ -148,9 +149,8 @@ class Pipelines(ApiRequestManager):
         :return:
         """
 
-        header = self.build_header(
-            org_id=org_id, others=self.content_type_header
-        )
+        header = self.build_header(aut_token=self.props.get_auth_token(cluster=self.cluster),
+                                   org_id=org_id, others=self.content_type_header)
 
         update_payload["name"] = str(pipeline_name)
 
@@ -215,6 +215,7 @@ class Pipelines(ApiRequestManager):
         :return:
         """
         headers = self.build_header(
+            aut_token=self.props.get_auth_token(cluster=self.cluster),
             org_id=org_id,
             others=self.content_type_header
         )
@@ -273,6 +274,7 @@ class Pipelines(ApiRequestManager):
         """
 
         headers = self.build_header(
+            aut_token=self.props.get_auth_token(cluster=self.cluster),
             org_id=org_id,
             others={"'Content-Type'": "application/data"}
         )
@@ -309,6 +311,7 @@ class Pipelines(ApiRequestManager):
         """
 
         header = self.build_header(
+            aut_token=self.props.get_auth_token(cluster=self.cluster),
             org_id=org_id,
             others=self.content_type_header
         )
@@ -343,6 +346,7 @@ class Pipelines(ApiRequestManager):
         """
 
         header = self.build_header(
+            aut_token=self.props.get_auth_token(cluster=self.cluster),
             org_id=org_id,
             others=self.content_type_header
         )
@@ -370,6 +374,7 @@ class Pipelines(ApiRequestManager):
         """
 
         header = self.build_header(
+            aut_token=self.props.get_auth_token(cluster=self.cluster),
             others=self.content_type_header
         )
 
@@ -396,6 +401,7 @@ class Pipelines(ApiRequestManager):
         """
 
         header = self.build_header(
+            aut_token=self.props.get_auth_token(cluster=self.cluster),
             org_id=org_id,
             others=self.content_type_header
         )
@@ -434,6 +440,7 @@ class Pipelines(ApiRequestManager):
             cols.append(('col', col_name))
 
         header = self.build_header(
+            aut_token=self.props.get_auth_token(cluster=self.cluster),
             org_id=org_id,
             others=self.content_type_header
         )
@@ -456,6 +463,7 @@ class Pipelines(ApiRequestManager):
         :return:
         """
         header = self.build_header(
+            aut_token=self.props.get_auth_token(cluster=self.cluster),
             others=self.content_type_header
         )
 
